@@ -6,13 +6,9 @@ from contextvars import ContextVar
 from typing import Any, Dict, List, Optional, Pattern, Union
 
 import stringcase
-from datamodel_code_generator import (
-    DataModelField,
-    cached_property,
-    load_yaml,
-    snooper_to_methods,
-)
+from datamodel_code_generator import cached_property, load_yaml, snooper_to_methods
 from datamodel_code_generator.imports import Import, Imports
+from datamodel_code_generator.model.pydantic import DataModelField
 from datamodel_code_generator.parser.jsonschema import (
     JsonSchemaObject,
     get_model_by_path,
@@ -113,6 +109,7 @@ class Operation(CachedPropertyModel):
     imports: List[Import] = []
     security: Optional[List[Dict[str, List[str]]]] = None
     components: Dict[str, Any] = {}
+    tags: Optional[List[str]]
     openapi_model_parser: OpenAPIModelParser
 
     @cached_property
@@ -142,7 +139,7 @@ class Operation(CachedPropertyModel):
                             required=requests.required,
                         )
                     )
-                    self.imports.extend(data_type.imports_)
+                    self.imports.extend(data_type.imports)
                 elif content_type == 'application/x-www-form-urlencoded':
                     arguments.append(
                         # TODO: support form with `Form()`
@@ -248,11 +245,11 @@ class Operation(CachedPropertyModel):
     def get_data_type(self, schema: JsonSchemaObject, suffix: str = '') -> DataType:
         if schema.ref:
             data_type = self.openapi_model_parser.get_ref_data_type(schema.ref)
-            data_type.imports_.append(
+            self.imports.append(
                 Import(
                     # TODO: Improve import statements
                     from_=model_module_name_var.get(),
-                    import_=data_type.type,
+                    import_=data_type.type_hint,
                 )
             )
             return data_type
@@ -271,14 +268,14 @@ class Operation(CachedPropertyModel):
             data_type = self.openapi_model_parser.parse_object(name, schema, path)
 
             self.imports.append(
-                Import(from_=model_module_name_var.get(), import_=data_type.type,)
+                Import(from_=model_module_name_var.get(), import_=data_type.type_hint,)
             )
             return data_type
 
         return self.openapi_model_parser.get_data_type(schema)
 
     def get_parameter_type(
-        self, parameter: Dict[str, Union[str, Dict[str, str]]], snake_case: bool
+        self, parameter: Dict[str, Union[str, Dict[str, Any]]], snake_case: bool
     ) -> Argument:
         ref: Optional[str] = parameter.get('$ref')  # type: ignore
         if ref:
@@ -287,7 +284,18 @@ class Operation(CachedPropertyModel):
         orig_name = name
         if snake_case:
             name = stringcase.snakecase(name)
-        schema: JsonSchemaObject = JsonSchemaObject.parse_obj(parameter["schema"])
+        content = parameter.get('content')
+        schema: Optional[JsonSchemaObject] = None
+        if content and isinstance(content, dict):
+            content_schema = [
+                c.get("schema")
+                for c in content.values()
+                if isinstance(c.get("schema"), dict)
+            ]
+            if content_schema:
+                schema = JsonSchemaObject.parse_obj(content_schema[0])
+        if not schema:
+            schema = JsonSchemaObject.parse_obj(parameter["schema"])
 
         field = DataModelField(
             name=name,
@@ -301,7 +309,7 @@ class Operation(CachedPropertyModel):
             ] = f"Query({'...' if field.required else repr(schema.default)}, alias='{orig_name}')"
             self.imports.append(Import(from_='fastapi', import_='Query'))
         else:
-            default = repr(schema.default) if 'default' in parameter["schema"] else None
+            default = repr(schema.default) if schema.has_default else None
         return Argument(
             name=field.name,
             type_hint=field.type_hint,
@@ -320,7 +328,7 @@ class Operation(CachedPropertyModel):
                     if RE_APPLICATION_JSON_PATTERN.match(content_type):
                         data_type = self.get_data_type(schema, 'response')
                         data_types.append(data_type)
-                        self.imports.extend(data_type.imports_)
+                        self.imports.extend(data_type.imports)
 
         if not data_types:
             return "None"
